@@ -23,7 +23,7 @@ resampling_method = function(option = "near") {
 
 #' Native interface to gdal utils
 #' @name gdal_utils
-#' @param util character; one of \code{info}, \code{warp}, \code{rasterize}, \code{translate}, \code{vectortranslate} (for ogr2ogr), \code{buildvrt}, \code{demprocessing}, \code{nearblack}, \code{grid}, \code{mdiminfo} and \code{mdimtranslate} (the last two requiring GDAL 3.1), \code{ogrinfo} (requiring GDAL 3.7)
+#' @param util character; one of \code{info}, \code{warp}, \code{rasterize}, \code{translate}, \code{vectortranslate} (for ogr2ogr), \code{buildvrt}, \code{demprocessing}, \code{nearblack}, \code{grid}, \code{mdiminfo} and \code{mdimtranslate} (the last two requiring GDAL 3.1), \code{ogrinfo} (requiring GDAL 3.7), \code{footprint} (requiring GDAL 3.8)
 #' @param source character; name of input layer(s); for \code{warp}, \code{buidvrt} or \code{mdimtranslate} this can be more than one
 #' @param destination character; name of output layer
 #' @param options character; options for the utility
@@ -33,12 +33,12 @@ resampling_method = function(option = "near") {
 #' @param colorfilename character; name of color file for \code{demprocessing} (mandatory if \code{processing="color-relief"})
 #' @return \code{info} returns a character vector with the raster metadata; all other utils return (invisibly) a logical indicating success (i.e., \code{TRUE}); in case of failure, an error is raised.
 #' @export
-#' @seealso \link{gdal_addo} for adding overlays to a raste file; \link{st_layers} to query geometry type(s) and crs from layers in a (vector) data source
+#' @seealso \link{gdal_addo} for adding overlays to a raster file; \link{st_layers} to query geometry type(s) and crs from layers in a (vector) data source
 #' @examples
 #'
 #' if (sf_extSoftVersion()["GDAL"] > "2.1.0") {
-#' # info utils can be used to list information about about a raster
-#' # dataset. More info: https://gdal.org/programs/ngdalinfo.html
+#' # info utils can be used to list information about a raster
+#' # dataset. More info: https://gdal.org/programs/gdalinfo.html
 #' in_file <- system.file("tif/geomatrix.tif", package = "sf")
 #' gdal_utils("info", in_file, options = c("-mm", "-proj4"))
 #'
@@ -54,7 +54,7 @@ resampling_method = function(option = "near") {
 #' )
 #' # The parameters can be specified as c("name") or c("name", "value"). The
 #' # vectortranslate utils can perform also various operations during the
-#' # conversion process. For example we can reproject the features during the
+#' # conversion process. For example, we can reproject the features during the
 #' # translation.
 #' gdal_utils(
 #'   util = "vectortranslate",
@@ -112,9 +112,10 @@ gdal_utils = function(util = "info", source, destination, options = character(0)
 						"-te", "-tr", "-tap", "-ts", "-ot")) # https://gdal.org/programs/gdal_rasterize.html
 				CPL_gdalrasterize(source, destination, options, oo, doo, config_options, overwrite, quiet)
 			}, # nocov end
+			footprint = CPL_gdalfootprint(source, destination, options, oo, config_options, quiet),
 			translate = CPL_gdaltranslate(source, destination, options, oo, config_options, quiet),
 			vectortranslate = CPL_gdalvectortranslate(source, destination, options, oo, doo, config_options, quiet),
-			buildvrt = CPL_gdalbuildvrt(source, destination, options, oo, config_options, quiet),
+			buildvrt = CPL_gdalbuildvrt(if (missing(source)) character(0) else source, destination, options, oo, config_options, quiet),
 			demprocessing = CPL_gdaldemprocessing(source, destination, options, processing, colorfilename, oo, config_options, quiet),
 			nearblack = CPL_gdalnearblack(source, destination, options, oo, config_options, doo, quiet),
 			grid = CPL_gdalgrid(source, destination, options, oo, config_options, quiet),
