@@ -26,6 +26,8 @@ format.sfc = function(x, ..., width = 30) {
 #' @param check_ring_dir see \link{st_read}
 #' @param dim character; if this function is called without valid geometries, this argument may carry the right dimension to set empty geometries
 #' @param recompute_bbox logical; use \code{TRUE} to force recomputation of the bounding box
+#' @param oriented logical; if \code{TRUE}, the ring is oriented such that left of the edges is inside the polygon; this is
+#' needed for convering polygons larger than half the globe to s2
 #' @return an object of class \code{sfc}, which is a classed list-column with simple feature geometries.
 #'
 #' @details A simple feature geometry list-column is a list of class
@@ -40,7 +42,7 @@ format.sfc = function(x, ..., width = 30) {
 #' d = st_sf(data.frame(a=1:2, geom=sfc))
 #' @export
 st_sfc = function(..., crs = NA_crs_, precision = 0.0, check_ring_dir = FALSE, dim,
-				  recompute_bbox = FALSE) {
+				  recompute_bbox = FALSE, oriented = NA) {
 	lst = list(...)
 	# if we have only one arg, which is already a list with sfg's, but NOT a geometrycollection:
 	# (this is the old form of calling st_sfc; it is way faster to call st_sfc(lst) if lst
@@ -137,6 +139,9 @@ st_sfc = function(..., crs = NA_crs_, precision = 0.0, check_ring_dir = FALSE, d
 #		if (length(u <- unique(sfg_classes[1L,])) > 1)
 #			stop(paste("found multiple dimensions:", paste(u, collapse = " ")))
 	}
+	if (isTRUE(oriented))
+		attr(lst, "oriented") = TRUE
+
 	lst
 }
 
@@ -255,9 +260,9 @@ print.sfc = function(x, ..., n = 5L, what = "Geometry set for", append = "") {
 		cat(paste0("First ", n, " geometries:\n"))
 	for (i in seq_len(min(n, length(x))))
 		if (inherits(x[[i]], "sfg"))
-			print(x[[i]], width = 50)
+			print(x[[i]], width = 50, crs = crs)
 		else
-			print(x[[i]])
+			print(x[[i]], crs = crs)
 	invisible(x)
 }
 
@@ -602,6 +607,59 @@ st_as_sfc.blob = function(x, ...) {
 #' @name st_as_sfc
 #' @export
 st_as_sfc.bbox = function(x, ...) {
-	box = st_polygon(list(matrix(x[c(1, 2, 3, 2, 3, 4, 1, 4, 1, 2)], ncol = 2, byrow = TRUE)))
-	st_sfc(box, crs = st_crs(x))
+	if (st_is_full(x))
+		st_as_sfc("POLYGON FULL", crs = st_crs(x))
+	else {
+		box = st_polygon(list(matrix(x[c(1, 2, 3, 2, 3, 4, 1, 4, 1, 2)], ncol = 2, byrow = TRUE)))
+		st_sfc(box, crs = st_crs(x), oriented = TRUE)
+	}
+}
+
+POLYGON_FULL = matrix(c(0,-90,0,-90), 2, byrow = TRUE)
+
+#' predicate whether a geometry is equal to a POLYGON FULL
+#'
+#' predicate whether a geometry is equal to a POLYGON FULL
+#' @param x object of class `sfg`, `sfc` or `sf`
+#' @param ... ignored, except when it contains a `crs` argument to inform unspecified `is_longlat`
+#' @returns logical, indicating whether geometries are POLYGON FULL (a spherical
+#' polygon covering the entire sphere)
+#' @export
+st_is_full = function(x, ...) UseMethod("st_is_full")
+
+#' @export
+#' @name st_is_full
+#' @param is_longlat logical; output of \link{st_is_longlat} of the parent `sfc` object
+st_is_full.sfg = function(x, ..., is_longlat = NULL) {
+	if (identical(is_longlat, FALSE)) # we know these are Cartesian coordinates:
+		FALSE
+	else
+		sf_use_s2() && inherits(x, "POLYGON") &&
+		length(x) == 1 && nrow(x[[1]]) == 2 && identical(x[[1]], POLYGON_FULL)
+}
+
+#' @export
+#' @name st_is_full
+st_is_full.sfc = function(x, ...) {
+	if (sf_use_s2() && inherits(x, c("sfc_POLYGON", "sfc_GEOMETRY"))) {
+		is_longlat = if (!is.null(attr(x, "crs")))
+				st_is_longlat(x)
+			else
+				NA
+		#sapply(x, st_is_full.sfg, ..., is_longlat = is_longlat)
+		sfc_is_full(x)
+	} else
+		rep_len(FALSE, length(x))
+}
+
+#' @export
+#' @name st_is_full
+st_is_full.sf = function(x, ...) {
+	st_is_full(st_geometry(x), ...)
+}
+
+#' @export
+#' @name st_is_full
+st_is_full.bbox = function(x, ...) {
+	sf_use_s2() && st_is_longlat(x) && all(x == c(-180,-90,180,90))
 }
