@@ -57,7 +57,14 @@ prnt.MULTIPOINT = function(x, ..., EWKT = TRUE, nested_parens = FALSE) {
 		  prnt.Matrix(x, nested_parens = nested_parens, ...))
 }
 prnt.LINESTRING = function(x, ..., EWKT = TRUE) paste(WKT_name(x, EWKT = EWKT), prnt.Matrix(x, ...))
-prnt.POLYGON = function(x, ..., EWKT = TRUE) paste(WKT_name(x, EWKT = EWKT), prnt.MatrixList(x, ...))
+
+prnt.POLYGON = function(x, ..., EWKT = TRUE) {
+	if (st_is_full(x, ...))
+		"POLYGON FULL"
+	else
+		paste(WKT_name(x, EWKT = EWKT), prnt.MatrixList(x, ...))
+}
+
 prnt.MULTILINESTRING = function(x, ..., EWKT = TRUE) paste(WKT_name(x, EWKT = EWKT), prnt.MatrixList(x, ...))
 prnt.MULTIPOLYGON = function(x, ..., EWKT = TRUE) paste(WKT_name(x, EWKT = EWKT), prnt.MatrixListList(x, ...))
 prnt.GEOMETRYCOLLECTION = function(x, ..., EWKT = TRUE) {
@@ -75,9 +82,9 @@ prnt.GEOMETRYCOLLECTION = function(x, ..., EWKT = TRUE) {
 #' @param ... modifiers; in particular \code{digits} can be passed to control the number of digits used
 #' @name st_as_text
 #' @details The returned WKT representation of simple feature geometry conforms to the
-#' \href{http://www.opengeospatial.org/standards/sfa}{simple features access} specification and extensions,
-#' \href{http://postgis.net/docs/using_postgis_dbmanagement.html#EWKB_EWKT}{known as EWKT}, supported by
-#' PostGIS and other simple features implementations for addition of SRID to a WKT string.
+#' \href{https://www.ogc.org/standard/sfa/}{simple features access} specification and extensions
+#' (known as EWKT, supported by PostGIS and other simple features implementations for addition of 
+#' a SRID to a WKT string).
 #'
 #' @export
 st_as_text = function(x, ...) UseMethod("st_as_text")
@@ -132,9 +139,8 @@ st_as_text.sfc = function(x, ..., EWKT = FALSE) {
 #' @rdname st_as_sfc
 #' @md
 #' @details If `x` is a character vector, it should be a vector containing
-#' [well-known-text](http://www.opengeospatial.org/standards/wkt-crs), or
-#' [Postgis EWKT](http://postgis.refractions.net/docs/using_postgis_dbmanagement.html#EWKB_EWKT) or
-#' GeoJSON representations of a single geometry for each vector element.
+#' [well-known-text](https://www.ogc.org/standard/wkt-crs/), or
+#' Postgis EWKT or GeoJSON representations of a single geometry for each vector element.
 #' @param crs integer or character; coordinate reference system for the
 #' @param GeoJSON logical; if \code{TRUE}, try to read geometries from GeoJSON text strings
 #' geometry, see [st_crs()]
@@ -165,6 +171,8 @@ st_as_sfc.character = function(x, crs = NA_integer_, ..., GeoJSON = FALSE) {
 			}
 			x = ewkt_to_wkt(x)
 		}
+		if (sf_use_s2() && !identical(st_is_longlat(crs), FALSE) && any(full <- (x == "POLYGON FULL")))
+			x[full] = "POLYGON((0 -90,0 -90))" # s2 struct for POLYGON FULL
 		ret = st_sfc(CPL_sfc_from_wkt(x))
 		st_crs(ret) = crs
 		ret
